==> jc-1.4.0.tar.gz: javax/swing/UIDefaults__24ProxyLazyValue__243.h <==
// final class javax.swing.UIDefaults$ProxyLazyValue$3

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f39b4c0ec4a13acf javax_swing_UIDefaults__24ProxyLazyValue__243

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_UIDefaults__24ProxyLazyValue__243_H_
#define _JC_javax_swing_UIDefaults__24ProxyLazyValue__243_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_UIDefaults$object;
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object;

// Typedefs
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_refs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_refs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_nonrefs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$refs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$refs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$nonrefs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$object	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$object;

typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vmethods	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vmethods;
typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtable	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtable;
typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtype	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtype;

// Constructors
extern void _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$method$_init$d546bd418ad99940(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$object *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_object_array *, struct _jc_object_array *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$method$createValue$5246839c46d82ae8(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$object *, struct _jc_javax_swing_UIDefaults$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$method_info$createValue$5246839c46d82ae8;

// Virtual methods structure
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vmethods {
	struct _jc_java_lang_Object$object	*(*createValue$5246839c46d82ae8)(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$object *, struct _jc_javax_swing_UIDefaults$object *);
};

// Vtable
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vmethods	javax_swing_UIDefaults__24ProxyLazyValue__243;
};

// Vtype
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtype {
	_jc_type			type;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_refs {
	struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object	*this;
	_jc_object_array	*val__24objs;
	_jc_object_array	*val__24clss;
	struct _jc_java_lang_String$object	*val__24className;
};

// Reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$refs {
    _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_refs	javax_swing_UIDefaults__24ProxyLazyValue__243;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_nonrefs	javax_swing_UIDefaults__24ProxyLazyValue__243;
};

// Object instance structure
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$object {
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtype	*vtype;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtype _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_UIDefaults__24ProxyLazyValue__243, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$class_object;

#endif	/* _JC_javax_swing_UIDefaults__24ProxyLazyValue__243_H_ */

==> jc-1.4.5.tar.gz: javax/swing/UIDefaults__24ProxyLazyValue__243.h <==
// final class javax.swing.UIDefaults$ProxyLazyValue$3

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f32849dbe9ba5cd5 javax_swing_UIDefaults__24ProxyLazyValue__243

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_UIDefaults__24ProxyLazyValue__243_H_
#define _JC_javax_swing_UIDefaults__24ProxyLazyValue__243_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_UIDefaults$object;
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object;

// Typedefs
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_refs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_refs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_nonrefs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$refs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$refs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$nonrefs	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$object	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$object;

typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vmethods	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vmethods;
typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtable	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtable;
typedef const struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtype	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtype;

// Constructors
extern void _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$method$_init$d546bd418ad99940(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$object *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object *, struct _jc_object_array *, struct _jc_object_array *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$method$createValue$5246839c46d82ae8(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$method_info$createValue$5246839c46d82ae8;

// Virtual methods structure
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vmethods {
	struct _jc_java_lang_Object$object	*(*createValue$5246839c46d82ae8)(_jc_env *, struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vmethods	javax_swing_UIDefaults__24ProxyLazyValue__243;
};

// Vtype
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtype {
	_jc_type			type;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_refs {
	struct _jc_javax_swing_UIDefaults__24ProxyLazyValue$object	*this;
	_jc_object_array	*val__24objs;
	_jc_object_array	*val__24clss;
	struct _jc_java_lang_String$object	*val__24className;
};

// Reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$refs {
    _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_refs	javax_swing_UIDefaults__24ProxyLazyValue__243;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$sub_nonrefs	javax_swing_UIDefaults__24ProxyLazyValue__243;
};

// Object instance structure
struct _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$object {
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtype	*vtype;
	_jc_javax_swing_UIDefaults__24ProxyLazyValue__243$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$vtype _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_UIDefaults__24ProxyLazyValue__243, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_UIDefaults__24ProxyLazyValue__243$class_object;

#endif	/* _JC_javax_swing_UIDefaults__24ProxyLazyValue__243_H_ */
